@@ -44,7 +44,7 @@ def download(client, file, nombre_imagen, srcdir, destdir, debug):
     # Keeps client and destdir arguments for compatibility reasons
     # but they're  not used
     f = open(file.path, 'r')
-    img = srcdir + '/' + nombre_imagen
+    img = destdir + '/' + nombre_imagen
     out = open(img, 'wb')
     out.write(f.read())
     out.close()
